/*  XRoar - a Dragon/Tandy Coco emulator
 *  Copyright (C) 2003  Ciaran Anscomb
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef GP32
#include "gp32/gptypes.h"
#else
#include <SDL/SDL.h>
#endif

#include "xroar.h"
#include "pia.h"
#include "keyboard.h"
#include "snapshot.h"
#include "logging.h"

static int matrix[9][9];

#ifdef GP32
#include "gp32/keyboard.c"
#else
#include "sdl/keyboard.c"
#endif

void keyboard_reset(void) {
	memset(matrix, 0, sizeof(matrix));
}

void keyboard_column_write(Uint8 mask) {
	Uint8 row = 0xff;
	int i, j;
	for (i = 0; i < 8; i++) {
		if ((mask & (1 << i)) == 0) {
			for (j = 0; j < 7; j++) {
				if (matrix[i][j]) {
					row &= ~(1 << j);
				}
			}
		}
	}
	pia_data_set(&PIA_0A, row);
}

void keyboard_row_write(Uint8 mask) {
	Uint8 col = 0xff;
	int i, j;
	for (i = 0; i < 7; i++) {
		if ((mask & (1 << i)) == 0) {
			for (j = 0; j < 8; j++) {
				if (matrix[j][i]) {
					col &= ~(1 << j);
				}
			}
		}
	}
	pia_data_set(&PIA_0B, col);
}
