/*  XRoar - a Dragon/Tandy Coco emulator
 *  Copyright (C) 2003  Ciaran Anscomb
 *
 *  See LICENSE for redistribution conditions. */

#ifndef __M6809_H__
#define __M6809_H__

#ifdef GP32
#include "gp32/gptypes.h"
#else
#include <SDL/SDL_types.h>
#endif

/* Either there's something wrong with my sound code, or there's something
 * funny about the Dragon's clock.  I've looked at the crystal and it's
 * definitely 14.31818MHz (this * 16) - but for some reason everything is
 * too fast unless I reduce the clock to 5/6 of what I think it should be
 * (a guess based on PAL vs NTSC framerates that happens to make everything
 * sound really good). */

#define M6809_CPU_RATE 894886.25
/*
#define M6809_CPU_RATE 745738.54166
*/

#define reg_a reg_accum.byte_values.upper
#define reg_b reg_accum.byte_values.lower
#define reg_d reg_accum.word_value

typedef union {
	Uint16 word_value;
	struct {
#if __BYTE_ORDER == __LITTLE_ENDIAN
		Uint8 lower;
		Uint8 upper;
#else
		Uint8 upper;
		Uint8 lower;
#endif
	} byte_values;
} accumulator_t;

extern Uint32 current_cycle;

extern Uint8 reg_cc, reg_dp;
extern Uint16 reg_x, reg_y, reg_u, reg_s, reg_pc;
extern accumulator_t reg_accum;

extern Uint32 nmi, firq, irq;
extern Uint32 wait_for_interrupt;
extern Uint32 skip_register_push;

void m6809_init(void);
void m6809_reset(void);
void m6809_cycle(void);
inline void m6809_nmi(void);
inline void m6809_firq(void);
inline void m6809_irq(void);

#endif  /* __M6809_H__ */
